==> lm_deluge-0.0.53.tar.gz: lm_deluge-0.0.53/src/lm_deluge/models/openai.py <==
OPENAI_MODELS = {
    #     ███████                                    █████████   █████
    #   ███░░░░░███                                 ███░░░░░███ ░░███
    #  ███     ░░███ ████████   ██████  ████████   ░███    ░███  ░███
    # ░███      ░███░░███░░███ ███░░███░░███░░███  ░███████████  ░███
    # ░███      ░███ ░███ ░███░███████  ░███ ░███  ░███░░░░░███  ░███
    # ░░███     ███  ░███ ░███░███░░░   ░███ ░███  ░███    ░███  ░███
    #  ░░░███████░   ░███████ ░░██████  ████ █████ █████   █████ █████
    #    ░░░░░░░     ░███░░░   ░░░░░░  ░░░░ ░░░░░ ░░░░░   ░░░░░ ░░░░░
    #                ░███
    #                █████
    #               ░░░░░
    "gpt-5": {
        "id": "gpt-5",
        "name": "gpt-5",
        "api_base": "https://api.openai.com/v1",
        "api_key_env_var": "OPENAI_API_KEY",
        "supports_json": False,
        "supports_logprobs": True,
        "supports_responses": True,
        "api_spec": "openai",
        "input_cost": 1.25,
        "cached_input_cost": 0.125,
        "output_cost": 10.0,
        "reasoning_model": True,
    },
    "gpt-5-chat": {
        "id": "gpt-5-chat",
        "name": "gpt-5-chat-latest",
        "api_base": "https://api.openai.com/v1",
        "api_key_env_var": "OPENAI_API_KEY",
        "supports_json": False,
        "supports_logprobs": True,
        "supports_responses": True,
        "api_spec": "openai",
        "input_cost": 1.25,
        "cached_input_cost": 0.125,
        "output_cost": 10.0,
        "reasoning_model": False,
    },
    "gpt-5-mini": {
        "id": "gpt-5-mini",
        "name": "gpt-5-mini",
        "api_base": "https://api.openai.com/v1",
        "api_key_env_var": "OPENAI_API_KEY",
        "supports_json": False,
        "supports_logprobs": True,
        "supports_responses": True,
        "api_spec": "openai",
        "input_cost": 0.25,
        "cached_input_cost": 0.025,
        "output_cost": 2.0,
        "reasoning_model": True,
    },
    "gpt-5-nano": {
        "id": "gpt-5-nano",
        "name": "gpt-5-nano",
        "api_base": "https://api.openai.com/v1",
        "api_key_env_var": "OPENAI_API_KEY",
        "supports_json": False,
        "supports_logprobs": True,
        "supports_responses": True,
        "api_spec": "openai",
        "input_cost": 0.05,
        "cached_input_cost": 0.005,
        "output_cost": 0.40,
        "reasoning_model": True,
    },
    "openai-computer-use-preview": {
        "id": "openai-computer-use-preview",
        "name": "computer-use-preview",
        "api_base": "https://api.openai.com/v1",
        "api_key_env_var": "OPENAI_API_KEY",
        "supports_json": True,
        "supports_logprobs": False,
        "supports_responses": True,
        "api_spec": "openai",
        "input_cost": 2.0,
        "output_cost": 8.0,
        "requests_per_minute": 20,
        "tokens_per_minute": 100_000,
        "reasoning_model": False,
    },
    "o3": {
        "id": "o3",
        "name": "o3-2025-04-16",
        "api_base": "https://api.openai.com/v1",
        "api_key_env_var": "OPENAI_API_KEY",
        "supports_json": False,
        "supports_logprobs": True,
        "supports_responses": True,
        "api_spec": "openai",
        "input_cost": 10.0,
        "output_cost": 40.0,
        "requests_per_minute": 20,
        "tokens_per_minute": 100_000,
        "reasoning_model": True,
    },
    "o4-mini": {
        "id": "o4-mini",
        "name": "o4-mini-2025-04-16",
        "api_base": "https://api.openai.com/v1",
        "api_key_env_var": "OPENAI_API_KEY",
        "supports_json": False,
        "supports_logprobs": True,
        "supports_responses": True,
        "api_spec": "openai",
        "input_cost": 1.1,
        "output_cost": 4.4,
        "requests_per_minute": 20,
        "tokens_per_minute": 100_000,
        "reasoning_model": True,
    },
    "gpt-4.1": {
        "id": "gpt-4.1",
        "name": "gpt-4.1-2025-04-14",
        "api_base": "https://api.openai.com/v1",
        "api_key_env_var": "OPENAI_API_KEY",
        "supports_json": True,
        "supports_logprobs": True,
        "supports_responses": True,
        "api_spec": "openai",
        "input_cost": 2.0,
        "output_cost": 8.0,
        "requests_per_minute": 20,
        "tokens_per_minute": 100_000,
        "reasoning_model": False,
    },
    "gpt-4.1-mini": {
        "id": "gpt-4.1-mini",
        "name": "gpt-4.1-mini-2025-04-14",
        "api_base": "https://api.openai.com/v1",
        "api_key_env_var": "OPENAI_API_KEY",
        "supports_json": True,
        "supports_logprobs": True,
        "supports_responses": True,
        "api_spec": "openai",
        "input_cost": 0.4,
        "output_cost": 1.6,
        "requests_per_minute": 20,
        "tokens_per_minute": 100_000,
        "reasoning_model": False,
    },
    "gpt-4.1-nano": {
        "id": "gpt-4.1-nano",
        "name": "gpt-4.1-nano-2025-04-14",
        "api_base": "https://api.openai.com/v1",
        "api_key_env_var": "OPENAI_API_KEY",
        "supports_json": True,
        "supports_logprobs": True,
        "supports_responses": True,
        "api_spec": "openai",
        "input_cost": 0.1,
        "output_cost": 0.4,
        "requests_per_minute": 20,
        "tokens_per_minute": 100_000,
        "reasoning_model": False,
    },
    "gpt-4.5": {
        "id": "gpt-4.5",
        "name": "gpt-4.5-preview-2025-02-27",
        "api_base": "https://api.openai.com/v1",
        "api_key_env_var": "OPENAI_API_KEY",
        "supports_json": False,
        "supports_logprobs": True,
        "supports_responses": True,
        "api_spec": "openai",
        "input_cost": 75.0,
        "output_cost": 150.0,
        "requests_per_minute": 20,
        "tokens_per_minute": 100_000,
        "reasoning_model": False,
    },
    "o3-mini": {
        "id": "o3-mini",
        "name": "o3-mini-2025-01-31",
        "api_base": "https://api.openai.com/v1",
        "api_key_env_var": "OPENAI_API_KEY",
        "supports_json": False,
        "supports_logprobs": True,
        "supports_responses": True,
        "api_spec": "openai",
        "input_cost": 1.1,
        "output_cost": 4.4,
        "requests_per_minute": 20,
        "tokens_per_minute": 100_000,
        "reasoning_model": True,
    },
    "o1": {
        "id": "o1",
        "name": "o1-2024-12-17",
        "api_base": "https://api.openai.com/v1",
        "api_key_env_var": "OPENAI_API_KEY",
        "supports_json": False,
        "supports_logprobs": True,
        "supports_responses": True,
        "api_spec": "openai",
        "input_cost": 15.0,
        "output_cost": 60.0,
        "requests_per_minute": 20,
        "tokens_per_minute": 100_000,
        "reasoning_model": True,
    },
    "o1-preview": {
        "id": "o1-preview",
        "name": "o1-preview-2024-09-12",
        "api_base": "https://api.openai.com/v1",
        "api_key_env_var": "OPENAI_API_KEY",
        "supports_json": False,
        "supports_logprobs": True,
        "supports_responses": True,
        "api_spec": "openai",
        "input_cost": 15.0,
        "output_cost": 60.0,
        "requests_per_minute": 20,
        "tokens_per_minute": 100_000,
        "reasoning_model": True,
    },
    "o1-mini": {
        "id": "o1-mini",
        "name": "o1-mini-2024-09-12",
        "api_base": "https://api.openai.com/v1",
        "api_key_env_var": "OPENAI_API_KEY",
        "supports_json": False,
        "supports_logprobs": True,
        "supports_responses": True,
        "api_spec": "openai",
        "input_cost": 3.0,
        "output_cost": 15.0,
        "requests_per_minute": 20,
        "tokens_per_minute": 100_000,
        "reasoning_model": True,
    },
    "gpt-4o": {
        "id": "gpt-4o",
        "name": "gpt-4o-2024-08-06",
        "api_base": "https://api.openai.com/v1",
        "api_key_env_var": "OPENAI_API_KEY",
        "supports_json": True,
        "supports_logprobs": True,
        "supports_responses": True,
        "api_spec": "openai",
        "input_cost": 5.0,
        "output_cost": 15.0,
        "requests_per_minute": 10_000,
        "tokens_per_minute": 30_000_000,
    },
    "gpt-4o-mini": {
        "id": "gpt-4o-mini",
        "name": "gpt-4o-mini-2024-07-18",
        "api_base": "https://api.openai.com/v1",
        "api_key_env_var": "OPENAI_API_KEY",
        "supports_json": True,
        "supports_logprobs": True,
        "supports_responses": True,
        "api_spec": "openai",
        "input_cost": 0.15,
        "output_cost": 0.6,
        "requests_per_minute": 60_000,
        "tokens_per_minute": 250_000_000,
    },
    "gpt-3.5-turbo": {
        "id": "gpt-3.5-turbo",
        "name": "gpt-3.5-turbo-0125",
        "api_base": "https://api.openai.com/v1",
        "api_key_env_var": "OPENAI_API_KEY",
        "supports_json": True,
        "supports_logprobs": True,
        "supports_responses": True,
        "api_spec": "openai",
        "input_cost": 0.5,
        "output_cost": 1.5,
        "requests_per_minute": 40_000,
        "tokens_per_minute": 75_000_000,
    },
    "gpt-4-turbo": {
        "id": "gpt-4-turbo",
        "name": "gpt-4-turbo-2024-04-09",
        "api_base": "https://api.openai.com/v1",
        "api_key_env_var": "OPENAI_API_KEY",
        "supports_json": True,
        "supports_logprobs": True,
        "supports_responses": True,
        "api_spec": "openai",
        "input_cost": 10.0,
        "output_cost": 30.0,
        "requests_per_minute": 10_000,
        "tokens_per_minute": 1_500_000,
    },
    "gpt-4": {
        "id": "gpt-4",
        "name": "gpt-4-0613",
        "api_base": "https://api.openai.com/v1",
        "api_key_env_var": "OPENAI_API_KEY",
        "supports_json": False,
        "supports_logprobs": False,
        "supports_responses": True,
        "api_spec": "openai",
        "input_cost": 30.0,
        "output_cost": 60.0,
        "requests_per_minute": 10_000,
        "tokens_per_minute": 300_000,
    },
    "gpt-4-32k": {
        "id": "gpt-4-32k",
        "name": "gpt-4-32k-0613",
        "api_base": "https://api.openai.com/v1",
        "api_key_env_var": "OPENAI_API_KEY",
        "supports_json": False,
        "supports_logprobs": False,
        "supports_responses": True,
        "api_spec": "openai",
        "input_cost": 60.0,
        "output_cost": 120.0,
        "requests_per_minute": 1_000,
        "tokens_per_minute": 150_000,
    },
}

==> lm_deluge-0.0.56.tar.gz: lm_deluge-0.0.56/src/lm_deluge/models/openai.py <==
OPENAI_MODELS = {
    #     ███████                                    █████████   █████
    #   ███░░░░░███                                 ███░░░░░███ ░░███
    #  ███     ░░███ ████████   ██████  ████████   ░███    ░███  ░███
    # ░███      ░███░░███░░███ ███░░███░░███░░███  ░███████████  ░███
    # ░███      ░███ ░███ ░███░███████  ░███ ░███  ░███░░░░░███  ░███
    # ░░███     ███  ░███ ░███░███░░░   ░███ ░███  ░███    ░███  ░███
    #  ░░░███████░   ░███████ ░░██████  ████ █████ █████   █████ █████
    #    ░░░░░░░     ░███░░░   ░░░░░░  ░░░░ ░░░░░ ░░░░░   ░░░░░ ░░░░░
    #                ░███
    #                █████
    #               ░░░░░
    "gpt-5": {
        "id": "gpt-5",
        "name": "gpt-5",
        "api_base": "https://api.openai.com/v1",
        "api_key_env_var": "OPENAI_API_KEY",
        "supports_json": False,
        "supports_logprobs": True,
        "supports_responses": True,
        "api_spec": "openai",
        "input_cost": 1.25,
        "cached_input_cost": 0.125,
        "output_cost": 10.0,
        "reasoning_model": True,
    },
    "gpt-5-chat": {
        "id": "gpt-5-chat",
        "name": "gpt-5-chat-latest",
        "api_base": "https://api.openai.com/v1",
        "api_key_env_var": "OPENAI_API_KEY",
        "supports_json": False,
        "supports_logprobs": True,
        "supports_responses": True,
        "api_spec": "openai",
        "input_cost": 1.25,
        "cached_input_cost": 0.125,
        "output_cost": 10.0,
        "reasoning_model": False,
    },
    "gpt-5-mini": {
        "id": "gpt-5-mini",
        "name": "gpt-5-mini",
        "api_base": "https://api.openai.com/v1",
        "api_key_env_var": "OPENAI_API_KEY",
        "supports_json": False,
        "supports_logprobs": True,
        "supports_responses": True,
        "api_spec": "openai",
        "input_cost": 0.25,
        "cached_input_cost": 0.025,
        "output_cost": 2.0,
        "reasoning_model": True,
    },
    "gpt-5-nano": {
        "id": "gpt-5-nano",
        "name": "gpt-5-nano",
        "api_base": "https://api.openai.com/v1",
        "api_key_env_var": "OPENAI_API_KEY",
        "supports_json": False,
        "supports_logprobs": True,
        "supports_responses": True,
        "api_spec": "openai",
        "input_cost": 0.05,
        "cached_input_cost": 0.005,
        "output_cost": 0.40,
        "reasoning_model": True,
    },
    "openai-computer-use-preview": {
        "id": "openai-computer-use-preview",
        "name": "computer-use-preview",
        "api_base": "https://api.openai.com/v1",
        "api_key_env_var": "OPENAI_API_KEY",
        "supports_json": True,
        "supports_logprobs": False,
        "supports_responses": True,
        "api_spec": "openai",
        "input_cost": 3.0,
        "output_cost": 12.0,
        "requests_per_minute": 20,
        "tokens_per_minute": 100_000,
        "reasoning_model": False,
    },
    "o3": {
        "id": "o3",
        "name": "o3-2025-04-16",
        "api_base": "https://api.openai.com/v1",
        "api_key_env_var": "OPENAI_API_KEY",
        "supports_json": False,
        "supports_logprobs": True,
        "supports_responses": True,
        "api_spec": "openai",
        "input_cost": 2.0,
        "cached_input_cost": 0.50,
        "output_cost": 8.0,
        "requests_per_minute": 20,
        "tokens_per_minute": 100_000,
        "reasoning_model": True,
    },
    "o4-mini": {
        "id": "o4-mini",
        "name": "o4-mini-2025-04-16",
        "api_base": "https://api.openai.com/v1",
        "api_key_env_var": "OPENAI_API_KEY",
        "supports_json": False,
        "supports_logprobs": True,
        "supports_responses": True,
        "api_spec": "openai",
        "input_cost": 1.1,
        "cached_input_cost": 0.275,
        "output_cost": 4.4,
        "requests_per_minute": 20,
        "tokens_per_minute": 100_000,
        "reasoning_model": True,
    },
    "gpt-4.1": {
        "id": "gpt-4.1",
        "name": "gpt-4.1-2025-04-14",
        "api_base": "https://api.openai.com/v1",
        "api_key_env_var": "OPENAI_API_KEY",
        "supports_json": True,
        "supports_logprobs": True,
        "supports_responses": True,
        "api_spec": "openai",
        "input_cost": 2.0,
        "cached_input_cost": 0.50,
        "output_cost": 8.0,
        "requests_per_minute": 20,
        "tokens_per_minute": 100_000,
        "reasoning_model": False,
    },
    "gpt-4.1-mini": {
        "id": "gpt-4.1-mini",
        "name": "gpt-4.1-mini-2025-04-14",
        "api_base": "https://api.openai.com/v1",
        "api_key_env_var": "OPENAI_API_KEY",
        "supports_json": True,
        "supports_logprobs": True,
        "supports_responses": True,
        "api_spec": "openai",
        "input_cost": 0.4,
        "cached_input_cost": 0.10,
        "output_cost": 1.6,
        "requests_per_minute": 20,
        "tokens_per_minute": 100_000,
        "reasoning_model": False,
    },
    "gpt-4.1-nano": {
        "id": "gpt-4.1-nano",
        "name": "gpt-4.1-nano-2025-04-14",
        "api_base": "https://api.openai.com/v1",
        "api_key_env_var": "OPENAI_API_KEY",
        "supports_json": True,
        "supports_logprobs": True,
        "supports_responses": True,
        "api_spec": "openai",
        "input_cost": 0.1,
        "cached_input_cost": 0.025,
        "output_cost": 0.4,
        "requests_per_minute": 20,
        "tokens_per_minute": 100_000,
        "reasoning_model": False,
    },
    "gpt-4.5": {
        "id": "gpt-4.5",
        "name": "gpt-4.5-preview-2025-02-27",
        "api_base": "https://api.openai.com/v1",
        "api_key_env_var": "OPENAI_API_KEY",
        "supports_json": False,
        "supports_logprobs": True,
        "supports_responses": True,
        "api_spec": "openai",
        "input_cost": 75.0,
        "output_cost": 150.0,
        "requests_per_minute": 20,
        "tokens_per_minute": 100_000,
        "reasoning_model": False,
    },
    "o3-mini": {
        "id": "o3-mini",
        "name": "o3-mini-2025-01-31",
        "api_base": "https://api.openai.com/v1",
        "api_key_env_var": "OPENAI_API_KEY",
        "supports_json": False,
        "supports_logprobs": True,
        "supports_responses": True,
        "api_spec": "openai",
        "input_cost": 1.1,
        "cached_input_cost": 0.55,
        "output_cost": 4.4,
        "requests_per_minute": 20,
        "tokens_per_minute": 100_000,
        "reasoning_model": True,
    },
    "o1": {
        "id": "o1",
        "name": "o1-2024-12-17",
        "api_base": "https://api.openai.com/v1",
        "api_key_env_var": "OPENAI_API_KEY",
        "supports_json": False,
        "supports_logprobs": True,
        "supports_responses": True,
        "api_spec": "openai",
        "input_cost": 15.0,
        "cached_input_cost": 7.50,
        "output_cost": 60.0,
        "requests_per_minute": 20,
        "tokens_per_minute": 100_000,
        "reasoning_model": True,
    },
    "o1-preview": {
        "id": "o1-preview",
        "name": "o1-preview-2024-09-12",
        "api_base": "https://api.openai.com/v1",
        "api_key_env_var": "OPENAI_API_KEY",
        "supports_json": False,
        "supports_logprobs": True,
        "supports_responses": True,
        "api_spec": "openai",
        "input_cost": 15.0,
        "output_cost": 60.0,
        "requests_per_minute": 20,
        "tokens_per_minute": 100_000,
        "reasoning_model": True,
    },
    "o1-mini": {
        "id": "o1-mini",
        "name": "o1-mini-2024-09-12",
        "api_base": "https://api.openai.com/v1",
        "api_key_env_var": "OPENAI_API_KEY",
        "supports_json": False,
        "supports_logprobs": True,
        "supports_responses": True,
        "api_spec": "openai",
        "input_cost": 1.1,
        "cached_input_cost": 0.55,
        "output_cost": 4.4,
        "requests_per_minute": 20,
        "tokens_per_minute": 100_000,
        "reasoning_model": True,
    },
    "gpt-4o": {
        "id": "gpt-4o",
        "name": "gpt-4o-2024-08-06",
        "api_base": "https://api.openai.com/v1",
        "api_key_env_var": "OPENAI_API_KEY",
        "supports_json": True,
        "supports_logprobs": True,
        "supports_responses": True,
        "api_spec": "openai",
        "input_cost": 2.50,
        "cached_input_cost": 1.25,
        "output_cost": 10.0,
        "requests_per_minute": 10_000,
        "tokens_per_minute": 30_000_000,
    },
    "gpt-4o-mini": {
        "id": "gpt-4o-mini",
        "name": "gpt-4o-mini-2024-07-18",
        "api_base": "https://api.openai.com/v1",
        "api_key_env_var": "OPENAI_API_KEY",
        "supports_json": True,
        "supports_logprobs": True,
        "supports_responses": True,
        "api_spec": "openai",
        "input_cost": 0.15,
        "cached_input_cost": 0.075,
        "output_cost": 0.6,
        "requests_per_minute": 60_000,
        "tokens_per_minute": 250_000_000,
    },
    "gpt-3.5-turbo": {
        "id": "gpt-3.5-turbo",
        "name": "gpt-3.5-turbo-0125",
        "api_base": "https://api.openai.com/v1",
        "api_key_env_var": "OPENAI_API_KEY",
        "supports_json": True,
        "supports_logprobs": True,
        "supports_responses": True,
        "api_spec": "openai",
        "input_cost": 0.5,
        "output_cost": 1.5,
        "requests_per_minute": 40_000,
        "tokens_per_minute": 75_000_000,
    },
    "gpt-4-turbo": {
        "id": "gpt-4-turbo",
        "name": "gpt-4-turbo-2024-04-09",
        "api_base": "https://api.openai.com/v1",
        "api_key_env_var": "OPENAI_API_KEY",
        "supports_json": True,
        "supports_logprobs": True,
        "supports_responses": True,
        "api_spec": "openai",
        "input_cost": 10.0,
        "output_cost": 30.0,
        "requests_per_minute": 10_000,
        "tokens_per_minute": 1_500_000,
    },
    "gpt-4": {
        "id": "gpt-4",
        "name": "gpt-4-0613",
        "api_base": "https://api.openai.com/v1",
        "api_key_env_var": "OPENAI_API_KEY",
        "supports_json": False,
        "supports_logprobs": False,
        "supports_responses": True,
        "api_spec": "openai",
        "input_cost": 30.0,
        "output_cost": 60.0,
        "requests_per_minute": 10_000,
        "tokens_per_minute": 300_000,
    },
    "gpt-4-32k": {
        "id": "gpt-4-32k",
        "name": "gpt-4-32k-0613",
        "api_base": "https://api.openai.com/v1",
        "api_key_env_var": "OPENAI_API_KEY",
        "supports_json": False,
        "supports_logprobs": False,
        "supports_responses": True,
        "api_spec": "openai",
        "input_cost": 60.0,
        "output_cost": 120.0,
        "requests_per_minute": 1_000,
        "tokens_per_minute": 150_000,
    },
}
